@@ -1,30 +1,32 @@
-
 import logging
 
-from sqlalchemy import Column, Boolean
-from sqlalchemy import Integer, String, DateTime
-from sqlalchemy.orm import relationship
-from sqlalchemy.sql.schema import ForeignKey, Index
-
-from .DeclarativeBase import DeclarativeBase
-from vortex.Tuple import Tuple, addTupleType
+from sqlalchemy import Boolean
+from sqlalchemy import Column
+from sqlalchemy import DateTime
+from sqlalchemy import Integer
+from sqlalchemy import String
+from sqlalchemy.sql.schema import Index
+from vortex.Tuple import Tuple
+from vortex.Tuple import addTupleType
 
 from peek_core_device._private.PluginNames import deviceTuplePrefix
+from .DeclarativeBase import DeclarativeBase
 
 logger = logging.getLogger(__name__)
 
 
 @addTupleType
 class DeviceUpdateTuple(Tuple, DeclarativeBase):
-    """ DeviceUpdateTuple
+    """DeviceUpdateTuple
 
     This table stores information about the peek device updates.
 
     """
-    __tablename__ = 'DeviceUpdate'
-    __tupleType__ = deviceTuplePrefix + 'DeviceUpdateTuple'
 
-    id = Column(Integer, primary_key=True)
+    __tablename__ = "DeviceUpdate"
+    __tupleType__ = deviceTuplePrefix + "DeviceUpdateTuple"
+
+    id = Column(Integer, primary_key=True, autoincrement=True)
     deviceType = Column(String(20), nullable=False)
     description = Column(String, nullable=False)
     buildDate = Column(DateTime(True), nullable=False)
@@ -36,6 +38,11 @@ class DeviceUpdateTuple(Tuple, DeclarativeBase):
     isEnabled = Column(Boolean, nullable=False, server_default="0")
 
     __table_args__ = (
-        Index("idx_DeviceUpdate_Version",
-              deviceType, appVersion, updateVersion, unique=True),
-    )
\ No newline at end of file
+        Index(
+            "idx_DeviceUpdate_Version",
+            deviceType,
+            appVersion,
+            updateVersion,
+            unique=True,
+        ),
+    )
