@@ -1,6 +1,7 @@
 from typing import Optional
 
-from vortex.Tuple import addTupleType, TupleField
+from vortex.Tuple import TupleField
+from vortex.Tuple import addTupleType
 from vortex.TupleAction import TupleActionABC
 
 from peek_core_device._private.PluginNames import deviceTuplePrefix
